@@ -59,7 +59,7 @@ class Copyright(dc.Copyright):
 
         try:
             with open(filename) as c:
-                copyright_ = Copyright(c)
+                copyright_ = Copyright(c, strict=False)
         except dc.NotMachineReadableError:
             return Copyright()
 
@@ -154,10 +154,11 @@ class Copyright(dc.Copyright):
                         dc.LicenseParagraph.create(paragraph.license)
 
             holders = []
-            for value in paragraph.copyright.split('\n'):
-                value = value.lstrip()
-                new_holders, _ = get_copyright_holders(value)
-                holders.extend(new_holders)
+            if paragraph.copyright:
+                for value in paragraph.copyright.split('\n'):
+                    value = value.lstrip()
+                    new_holders, _ = get_copyright_holders(value)
+                    holders.extend(new_holders)
             group.add_copyrights(holders)
 
             for filename in files:
@@ -213,7 +214,12 @@ class Copyright(dc.Copyright):
     def get_group_dict(self, options):
         groups = {}
         for group in self.groups:
-            groups[group.get_key(options)] = group
+            key = group.get_key(options)
+            if key in groups:
+                for fileinfo in group.files:
+                    groups[key].add_file(fileinfo)
+            else:
+                groups[key] = group
         return groups
 
 
